//
// CategoryErrorListener.h
//	
//	Get notification when an error occurs on a Category.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

#ident "$Revision: 1.5 $"
#ifndef _SYSADM_CATEGORY_ERROR_LISTENER_H
#define _SYSADM_CATEGORY_ERROR_LISTENER_H

#include <sysadm/CategoryErrorEvent.h>

BEGIN_NAMESPACE(sysadm);

//
// An instance of a subclass of CategoryErrorListener receives
// notification of Category errors.
//
// See Category.h for details on how CategoryErrorListener instances can be
// used with a Category instance.
//
// CategoryErrorListener instances are mostly used by the Category Service,
// described in sysadmd(1M), to fulfill requests from remote clients.
// They can also be used by any server-side components that need to
// know about errors from a Category.
//
class CategoryErrorListener {

  public:
    // Constructor
    CategoryErrorListener();

    // Called when an error occurs on the Category that it is
    // registered with.
    virtual void categoryError(CategoryErrorEvent& event) = 0;
    
  private:
    
    // Intentionally undefined.
    CategoryErrorListener(const CategoryErrorListener&);
    CategoryErrorListener& operator=(const CategoryErrorListener&);

};

END_NAMESPACE(sysadm);
#endif  //  _SYSADM_CATEGORY_ERROR_LISTENER_H
