//
// Authenticator.h
//
//	Base class for authentication schemes.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

#ident "$Revision: 1.3 $"
#ifndef _SYSADM_AUTHENTICATOR_H
#define _SYSADM_AUTHENTICATOR_H

#include <sysadm/Connection.h>
#include <sysadm/ResultListener.h>

BEGIN_NAMESPACE(sysadm);

//
// Authenticator is the base class for authentication schemes.
// Authentication parameters are exchanged using a Connection object.
//
class Authenticator {
  public:

    // Constructor.
    Authenticator();

    // Destructor.
    virtual ~Authenticator();

    // Set the connection to be used for exchanging authentication
    // parameters.
    virtual void setConnection(Connection* conn);

    // Exchange authentication parameters.  Notify caller of result
    // via "adoptedResultListener".
    virtual void authenticate(ResultListener* adoptedListener) = 0;

  protected:

    // Accessor for our connection.
    Connection* getConnection();

  private:
    Connection* _conn;
};

END_NAMESPACE(sysadm);
#endif  //  _SYSADM_AUTHENTICATOR_H
